@@ -11,9 +11,17 @@ sub smtpauth
 {
 	$username	= Exim::expand_string('$1');
 	$password	= Exim::expand_string('$2');
+	$extra		= Exim::expand_string('$3');
 	$domain		= "";
 	$unixuser	= 1;
 
+	#check for netscape that offsets the login/pass by one
+	if ($username eq "" && length($extra) > 0)
+	{
+		$username = $password;
+		$password = $extra;
+	}
+
 	if ($username =~ /\@/)
 	{
 		$unixuser = 0;
